import { GridTabulator, defaultGridTabulatorConfig, gridTabulatorShadowOptions, } from '@genesislcap/grid-tabulator';
import { rapidGridTabulatorStyles as styles } from './grid-tabulator.styles';
import { rapidGridTabulatorTemplate as template } from './grid-tabulator.template';
import { themeGenesisRapidDarkName, themeGenesisRapidName } from './themes';
const defaultRowHeaderHeight = 40;
const defaultRapidTheme = 'tabulator-theme-genesis-rapid-dark';
/**
 * @tagname %%prefix%%-grid-tabulator
 */
export class RapidGridTabulator extends GridTabulator {
    constructor() {
        super(...arguments);
        /**
         * Sets default theme to Rapid
         * @override
         */
        this.theme = defaultRapidTheme;
    }
    themeChanged(oldValue, newValue) {
        if (!oldValue && newValue !== defaultRapidTheme)
            return;
        super.themeChanged(oldValue, newValue);
    }
    /**
     * Gets the grid options
     */
    get gridOptions() {
        return super.gridOptions;
    }
    /**
     * Handles extra RAPID configs and options
     * @override
     */
    set gridOptions(options) {
        // options.components = {
        //   [GridTabulatorRendererTypes.action]: RapidAgActionRenderer,
        //   [GridTabulatorRendererTypes.actionsMenu]: RapidAgActionsMenuRenderer,
        //   [GridTabulatorRendererTypes.boolean]: RapidBooleanRenderer,
        // };
        var _a;
        const isRapidTheme = this.theme === themeGenesisRapidName || this.theme === themeGenesisRapidDarkName;
        if (isRapidTheme) {
            // this.headerHeight = options.headerHeight ?? defaultRowHeaderHeight;
            this.rowHeight = (_a = options.rowHeight) !== null && _a !== void 0 ? _a : defaultRowHeaderHeight;
        }
        super.gridOptions = options;
    }
}
// explicitly declaring for extensibility
export const rapidGridTabulatorShadowOptions = gridTabulatorShadowOptions;
export const rapidGridTabulatorDefaultConfig = defaultGridTabulatorConfig;
export const rapidGridTabulator = RapidGridTabulator.compose(Object.assign({ baseName: 'grid-tabulator', template,
    styles, shadowOptions: rapidGridTabulatorShadowOptions }, rapidGridTabulatorDefaultConfig));
